#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Deal flow espaces verts 2018 - 2019
# 
# Ce jeu de données est proposé pour la réalisation d'un projet de module python pour partager une fonction de graphe. Un exemple de ce projet est proposé : [td2a_plotting](https://github.com/sdpython/td2a_plotting).

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[2]:


get_ipython().run_line_magic('matplotlib', 'inline')


# ## Récupération des données

# In[3]:


from ensae_teaching_cs.data import deal_flow_espace_vert_2018_2019
filenames = deal_flow_espace_vert_2018_2019()
filenames


# In[4]:


import pandas
df19 = pandas.read_excel(filenames[0], engine='openpyxl')
df19.head()


# L'encoding du fichier *csv* n'est pas évident à deviner. On utilise le module [chardet](https://chardet.readthedocs.io/en/latest/usage.html) pour cela.

# In[5]:


import chardet
with open(filenames[1], 'rb') as f:
    c = f.read()
chardet.detect(c)


# In[6]:


df18 = pandas.read_csv(filenames[1], encoding="Windows-1252", sep=";", decimal=',')
df18.head()


# Comparons les colonnes.

# In[7]:


df18.columns


# In[8]:


df19.columns


# ## Vues dynamiques

# On regarde un peu les données.

# In[9]:


columns = list(sorted(set(list(df18.columns) +  list(df19.columns)))) + ['montant']


# In[10]:


from ipywidgets import interact


# In[11]:


@interact(annee=[2018, 2019], column=columns, x=(0, 10000000, 100000))
def show_rows(annee=2018, column='montant', x=100000):
    if annee == 2018:
        if column == 'montant':
            column = 'iMontantTotal'
        return df18[df18[column] >= x].sort_values(column).T
    else:
        if column == 'montant':
            column = 'iMontant total'
        return df19[df19[column] >= x].sort_values(column).T


# ## Une carte
# 
# On regarde les projets sur la métropole en 2018.

# In[12]:


lim_metropole = [-5, 10, 41, 52]

df18_metro = df18[((df18.COMMUNE_X >= lim_metropole[0]) & (df19.COMMUNE_X <= lim_metropole[1]) &
                   (df18.COMMUNE_Y >= lim_metropole[2]) & (df19.COMMUNE_Y <= lim_metropole[3]))]
df18.shape, df18_metro.shape


# In[13]:


import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib.pyplot as plt

fig = plt.figure(figsize=(7, 7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax.set_extent(lim_metropole)
ax.add_feature(cfeature.OCEAN.with_scale('50m'))
ax.add_feature(cfeature.COASTLINE.with_scale('50m'))
ax.add_feature(cfeature.RIVERS.with_scale('50m'))
ax.add_feature(cfeature.BORDERS.with_scale('50m'), linestyle=':')
ax.scatter(df18_metro.COMMUNE_X, df18_metro.COMMUNE_Y,
           s=df18_metro.iMontantTotal ** 0.5 / 20, alpha=0.5)
ax.set_title('France 2018\ninvestissements verts');
# debug


# In[14]: